@@ -1,15 +1,9 @@
-from marshmallow.fields import (
-    Nested,
-    Str,
-)
-from marshmallow.validate import (
-    OneOf,
-)
-from .object_type import (
-    FEATURE,
-)
+from marshmallow.fields import Nested, Str
+from marshmallow.validate import OneOf
+
 from ._base import BaseSchema
 from .geometry import GeometriesSchema
+from .object_type import FEATURE
 from .property import PropertiesSchema
 
 
