@@ -1,18 +1,8 @@
-from marshmallow.fields import (
-    Tuple,
-    Str,
-)
-from marshmallow.validate import (
-    OneOf,
-)
-from .object_type import (
-    POINT,
-)
-from ._base import (
-    BaseSchema,
-    lon,
-    lat,
-)
+from marshmallow.fields import Str, Tuple
+from marshmallow.validate import OneOf
+
+from ._base import BaseSchema, lat, lon
+from .object_type import POINT
 
 
 class PointSchema(BaseSchema):
